@@ -2,7 +2,7 @@ import json
 import pandas as pd
 from sqlalchemy import create_engine
 
-class bgmysqlUtil:
+class mysqlUtil:
     def __init__(self):
         __mysql_username = 'test'
         __mysql_password = 'test'
